@@ -105,6 +105,9 @@ bool KExifData::readFromFile(const QString& filename)
 
     // -- Load thumbnail -------------------------------------
 
+    // FIXME (gilles-03/28/06): Loading thumbs with Qt using all Exif data is badly interpreted by QT about orientation.
+    //                          to fix it, we need to pass to QImage instance only thumbs image data from Exif, not all!
+
     if (d->exifData->data) {
         d->thumbnail.loadFromData(d->exifData->data,
                                 d->exifData->size);
@@ -222,11 +225,11 @@ QDateTime KExifData::getExifDateTime() const
       if (entry)
       {
 #ifdef HAVE_EXIF06
-          char val[1024];
-          exif_entry_get_value(entry, val, 1023);
+          QCString cstr(1024);
+          exif_entry_get_value(entry, cstr.data(), cstr.size()-1);
           // just in case we don't get a null-terminated string
-          val[1024] = '\0'; 
-          QString str((const char*)&val);
+          cstr[cstr.size()-1] = '\0'; 
+          QString str = QString::fromLatin1(cstr.data());
 #else
           QString str(exif_entry_get_value(entry));
 #endif
@@ -246,11 +249,11 @@ QDateTime KExifData::getExifDateTime() const
       if (entry)
       {
 #ifdef HAVE_EXIF06
-          char val[1024];
-          exif_entry_get_value(entry, val, 1023);
+          QCString cstr(1024);
+          exif_entry_get_value(entry, cstr.data(), cstr.size()-1);
           // just in case we don't get a null-terminated string
-          val[1024] = '\0'; 
-          QString str((const char*)&val);
+          cstr[cstr.size()-1] = '\0'; 
+          QString str = QString::fromLatin1(cstr.data());
 #else
           QString str(exif_entry_get_value(entry));
 #endif
@@ -265,11 +268,11 @@ QDateTime KExifData::getExifDateTime() const
       if (entry)
       {
 #ifdef HAVE_EXIF06
-          char val[1024];
-          exif_entry_get_value(entry, val, 1023);
+          QCString cstr(1024);
+          exif_entry_get_value(entry, cstr.data(), cstr.size()-1);
           // just in case we don't get a null-terminated string
-          val[1024] = '\0'; 
-          QString str((const char*)&val);
+          cstr[cstr.size()-1] = '\0'; 
+          QString str = QString::fromLatin1(cstr.data());
 #else
           QString str(exif_entry_get_value(entry));
 #endif
